# -*- coding: utf-8 -*-

# mapWOC
#
# Description: Test URLList-URL mapping of db.
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import json
import unittest
import os
import shutil
import datetime
import time
import tarfile
import gzip
import ConfigParser
import Queue

from sqlalchemy import *

from mapwoc.lib.url import URL, create_URL_List, URLList
from mapwoc.lib.model.result import *
from mapwocgui.model.meta import Session

class TestURLsinDB(unittest.TestCase):

    def setUp(self):
        if not os.path.isdir("tests/tmp"):
            os.mkdir("tests/tmp")
        self.dbpath = "tests/tmp/tmpdb.db"
        shutil.copyfile("tests/dbs/database.db", self.dbpath)
        engine = create_engine('sqlite:///tests/tmp/tmpdb.db')
        __c = engine.connect()
        Session.configure(bind=engine)

    def tearDown(self):
        Session.remove() # Necessary to "clear the cache"
        os.remove("tests/tmp/tmpdb.db")

    def test_multi_duplicate_urllist(self):
        urllist = URLList("List")
        u1 = URL("http://one.com")
        u2 = URL("http://two.com")
        u3 = URL("http://three.com")
        urllist.urls = [u1, u2, u3, u1, u2, u3]
        Session.add(urllist)
        Session.add(u1)
        Session.add(u2)
        Session.add(u3)
        Session.commit()
        self.assertEqual(len(urllist.urls), 3, "URL-List cannot contain same url multiple times.")
        self.assertTrue(urllist.urls[0].url == "http://one.com", "First URL of URLList changed after commit.")
